@@ -15,7 +15,7 @@ from sim2bids.validate import validate
 JE_FIELDS = ['Units', 'Description', 'CoordsRows', 'CoordsColumns', 'ModelEq', 'ModelParam', 'SourceCode',
              'SourceCodeVersion', 'SoftwareVersion', 'SoftwareName', 'SoftwareRepository', 'Network']
 UNITS = ['s', 'm', 'ms', 'degrees', 'radians']
-OPTIONS = ['App 101', 'Preprocess data', 'Supported files', 'Functionality', 'BEP034']
+OPTIONS = ['App 101', 'Preprocess data', 'BEP034']
 REQUIRED = None
 AUTOFILL = True
 
@@ -55,10 +55,6 @@ class MainArea(param.Parameterized):
                                               options=checkbox_options,
                                               margin=(-20, 10, 0, 10))
 
-    # rhythms = pn.Column('#### Specify rhythms', pn.widgets.CheckBoxGroup(
-    #     value=[], options=['Alpha', 'Beta', 'Delta', 'Gamma', 'Theta'],
-    #     inline=True, margin=(-10, 0, 0, 10)))
-
     speed = pn.Column('#### Specify `conduction speed` folder name',
                       pn.widgets.TextInput(value=app.COND_SPEED, margin=(-10, 0, 0, 0)))
 
@@ -101,6 +97,8 @@ class MainArea(param.Parameterized):
             self.to_rename_path = []
             self.structure.value = []
             self.rename_files = pn.WidgetBox()
+            self.to_rename = None
+            self.to_rename_path = None
 
         if len(selected) > 0:
             # check files for preprocessing step
@@ -108,6 +106,7 @@ class MainArea(param.Parameterized):
             path = self.text_input.value
             app.preprocess_input(path, selected)
             self.to_rename = validate.filter(app_utils.get_content(path, selected, basename=True))
+            print(self.to_rename)
             self.to_rename_path = validate.filter(app_utils.get_content(path, selected), self.to_rename)
 
             if len(self.to_rename) > len(self.rename_files) + 1:
@@ -120,8 +119,13 @@ class MainArea(param.Parameterized):
             self.length = len(selected)
 
     def _generate_files(self, event=None):
-        _ = app.main(path=self.text_input.value, files=self.cross_select.value,
-                          subs=self.subjects, save=True, layout=True)
+        if validate.IS_RENAMED:
+            _ = app.main(path=self.text_input.value,
+                         files=utils.get_all_files(validate.RENAMED, self.cross_select.value, self.text_input.value),
+                         subs=self.subjects, save=True, layout=True)
+        else:
+            _ = app.main(path=self.text_input.value, files=self.cross_select.value,
+                              subs=self.subjects, save=True, layout=True)
         app.ALL_FILES = None
         utils.reset_values()
 
@@ -171,8 +175,10 @@ class MainArea(param.Parameterized):
             app.OUTPUT = output
 
     def _rename(self, event=None):
-
         validate.validate(self.rename_files, self.to_rename_path, self.text_input.value, self.cross_select.value)
+        self.rename_files = pn.WidgetBox()
+        self.to_rename = None
+        self.to_rename_path = None
 
     @pn.depends('desc.value', watch=True)
     def _change_desc(self):
@@ -184,14 +190,16 @@ class MainArea(param.Parameterized):
             ('Select Files', pn.Column(pn.pane.Markdown(GET_STARTED),
                                        self.text_input,
                                        self.cross_select,
-                                       pn.Row(
-                                           pn.Param(self, parameters=['gen_struct'],
-                                                    show_name=False,
-                                                    widgets={'gen_struct': {'button_type': 'primary'}}),
-                                           pn.Param(self, parameters=['gen_btn'],
-                                                    show_name=False, widgets={'gen_btn': {'button_type': 'primary'}}),
-                                           sizing_mode='stretch_width', margin=(50, 0, 0, 0)
-                                       ),
+                                       pn.Param(self, parameters=['gen_btn'],
+                                                show_name=False, widgets={'gen_btn': {'button_type': 'primary'}}),
+                                       # pn.Row(
+                                       #     pn.Param(self, parameters=['gen_struct'],
+                                       #              show_name=False,
+                                       #              widgets={'gen_struct': {'button_type': 'primary'}}),
+                                       #     pn.Param(self, parameters=['gen_btn'],
+                                       #              show_name=False, widgets={'gen_btn': {'button_type': 'primary'}}),
+                                       #     sizing_mode='stretch_width', margin=(50, 0, 0, 0)
+                                       # ),
                                        self.structure)),
             ('Preprocess Data', self.rename_files),
             ('View Results', ViewResults().view()),
@@ -201,22 +209,20 @@ class MainArea(param.Parameterized):
 
         sidebar = pn.Column(
             '## Settings',
-            '#### Provide input path',
-            self.input_path,
             '#### Provide output path',
             self.output_path,
-            '#### Provide short description (max 30 chars)',
-            self.desc,
-            '#### Select additional settings',
-            self.checkbox_group,
-            '#### Specify simulation information',
-            self.speed, self.global_coupling
+            # '#### Provide short description (max 30 chars)',
+            # self.desc,
+            # '#### Select additional settings',
+            # self.checkbox_group,
+            # # '#### Specify simulation information',
+            # self.speed, self.global_coupling
         )
 
         return pn.template.MaterialTemplate(
             title='Preprocess | Transform | Download',
-            sidebar=sidebar,
-            site='INCF',
+            # sidebar=sidebar,
+            site='sim2bids',
             main=main,
             header_background='#4488c4'
         )
@@ -312,9 +318,7 @@ class UserGuide(param.Parameterized):
         super().__init__(**params)
         self.map = {OPTIONS[0]: ug.how_to_use,
                     OPTIONS[1]: ug.preprocess,
-                    OPTIONS[2]: ug.supported,
-                    OPTIONS[3]: ug.functionality,
-                    OPTIONS[4]: ug.bep034}
+                    OPTIONS[-1]: ug.bep034}
         self.text = pn.widgets.StaticText(value=self.map[OPTIONS[0]])
 
     @pn.depends('user_guide.value', watch=True)
@@ -322,7 +326,7 @@ class UserGuide(param.Parameterized):
         self.text.value = self.map[self.user_guide.value]
 
     def view(self):
-        return pn.Column(self.user_guide, self.text, scroll=True, height=600)
+        return pn.Column(self.user_guide, self.text, scroll=True, height=800)
 
 
 def update_files(content):
@@ -364,8 +368,7 @@ Here you can select the folder(s) that you want to transform. Beware that we are
 content available in the specified folder. That means if the folder contains a sub-folder, we will transform the content
 if it falls into the accepted file formats.
 
-You can get a preliminary look into the to-be-generated structure by clicking on **Show Structure** button. If you're 
-happy with the results, you can click on **Generate Files** button to physically save the results. After that, please 
+Click on **Generate Files** button to physically save the results. After that, please 
 **make sure to give user-specific input** by clicking on **View Results** tab and selecting JSON files. You'll see a lot
 of required and recommended fields that can be updated. By default, all required fields are already provided. However,
 you have all the rights to change them. See further details in **User Guide**. 
